============
Contributors
============

People, who contributed to Kibitzr in arbitrary order:

* `Igor Sobolev <https://github.com/yigor>`_
* `Delirious Lettuce <https://github.com/delirious-lettuce>`_
* `Martin Virtel <https://github.com/mvtango>`_
* `Attila Nagy <https://github.com/attilanagy>`_
* `Niklas Heer <https://github.com/niklas-heer>`_
* `Francesco Barresi <https://github.com/cescobarresi>`_
* `Maciek Starzyk <https://github.com/mstarzyk>`_
* `ColdIce <https://github.com/ColdIce1>`_
* `Jesaja Everling <https://github.com/jeverling>`_
* `egvimo <https://github.com/egvimo>`_
* `fi-do <https://github.com/fi-do>`_
* `QJKX <https://github.com/QJKX>`_
* `Ivan Zarudny <https://github.com/mcrozz>`_
* `Colin Unger <https://github.com/lockshaw>`_
